=========
LazyFrame
=========

This page gives an overview of all public LazyFrame methods.

.. toctree::
   :maxdepth: 2
   :hidden:

   aggregation
   attributes
   descriptive
   group_by
   modify_select
   miscellaneous
   in_process
   gpu_engine

.. _lazyframe:

.. currentmodule:: polars

.. autoclass:: LazyFrame
    :members:
    :noindex:
    :autosummary:
    :autosummary-nosignatures:
